"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.job import Job
globals()['Job'] = Job
from delphix.api.gateway.model.create_ase_source_response import CreateAseSourceResponse


class TestCreateAseSourceResponse(unittest.TestCase):
    """CreateAseSourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateAseSourceResponse(self):
        """Test CreateAseSourceResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateAseSourceResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
